@@ -43,6 +43,7 @@ class SungrowModbusTcpClient(ModbusTcpClient):
               self._setup()
            else:
               self._key = b'no encryption'
+              self._key_date = date.today()
 
     def connect(self):
         self.close()
@@ -53,6 +54,10 @@ class SungrowModbusTcpClient(ModbusTcpClient):
            self._getkey()
         return result
 
+    def close(self):
+       ModbusTcpClient.close(self)
+       self._fifo = bytes()
+
     def _send_cipher(self, request):
         self._fifo = bytes()
         length = len(request)
